PCB Environment: LayerAlphaSlider Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
LayerAlphaSlider Class Reference
Inheritance diagram for LayerAlphaSlider:

## Public Member Functions
| LayerAlphaSlider (ViewTab *, int layerIndex)
int | getLayer () const
QSlider * | getSlider () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/ViewTab.hpp